Package: speckle
Type: Package
Title: Statistical methods for analysing single cell RNA-seq data
Version: 1.13.0
Date: 2025-10-14
Authors@R: 
  c(person(given = "Belinda",
           family = "Phipson",
           role = c("aut", "cre"),
           email = "phipson.b@wehi.edu.au")
    )
LazyData: FALSE
Depends: R (>= 4.2.0)
Imports: limma, edgeR, SingleCellExperiment, Seurat, ggplot2, methods,
        stats, grDevices, graphics
VignetteBuilder: knitr
Suggests: BiocStyle, knitr, rmarkdown, statmod, CellBench, scater,
        patchwork, jsonlite, vdiffr, testthat (>= 3.0.0)
Description: The speckle package contains functions for the analysis of single cell RNA-seq data. The speckle package currently contains functions to analyse differences in cell type proportions. There are also functions to estimate the parameters of the Beta distribution based on a given counts matrix, and a function to normalise a counts matrix to the median library size. There are plotting functions to visualise cell type proportions and the mean-variance relationship in cell type proportions and counts. As our research into specialised analyses of single cell data continues we anticipate that the package will be updated with new functions.
License: GPL-3
biocViews: SingleCell, RNASeq, Regression, GeneExpression
RoxygenNote: 7.2.2
Encoding: UTF-8
Config/testthat/edition: 3
git_url: https://git.bioconductor.org/packages/speckle
git_branch: devel
git_last_commit: 784ac53
git_last_commit_date: 2026-04-28
Repository: Bioconductor 3.24
Date/Publication: 2026-04-28
NeedsCompilation: no
Packaged: 2026-04-29 01:19:01 UTC; biocbuild
Author: Belinda Phipson [aut, cre]
Maintainer: Belinda Phipson <phipson.b@wehi.edu.au>
