# Generated by roxygen2: do not edit by hand

export(convertDataToList)
export(estimateBetaParam)
export(estimateBetaParamsFromCounts)
export(getTransformedProps)
export(ggplotColors)
export(normCounts)
export(plotCellTypeMeanVar)
export(plotCellTypeProps)
export(plotCellTypePropsMeanVar)
export(propeller)
export(propeller.anova)
export(propeller.ttest)
export(speckle_example_data)
importFrom(Seurat,Idents)
importFrom(SingleCellExperiment,colData)
importFrom(edgeR,DGEList)
importFrom(edgeR,estimateDisp)
importFrom(ggplot2,aes)
importFrom(ggplot2,element_text)
importFrom(ggplot2,geom_bar)
importFrom(ggplot2,ggplot)
importFrom(ggplot2,theme)
importFrom(grDevices,hcl)
importFrom(graphics,legend)
importFrom(graphics,lines)
importFrom(graphics,par)
importFrom(graphics,title)
importFrom(limma,contrasts.fit)
importFrom(limma,eBayes)
importFrom(limma,lmFit)
importFrom(methods,is)
importFrom(stats,lowess)
importFrom(stats,median)
importFrom(stats,p.adjust)
importFrom(stats,var)
